% This script initializes the circular sun synchronous orbit at the Spring
% equinox, it computes the rotaion matrix C from LVLH to ECI Earth
% reference frame through the Euler's angles C=C3'(RAAN)C1'(i)C3'(argp),
% and gives the Target frame for reference to the satellite. It computes
% also the rotation matrix Ct from ECI to LVLH.%

% Questo script inizializza l'orbita eliosincrona circolare all'equinozio
% di primavera, calcola la matrice di rotazione C dal sistema di
% riferimento LVLH al sistema di riferimento ECI mediante gli angoli di
% Eulero C=C3'(RAAN)C1'(i)C3'(argp), e d la erna obiettivo come
% riferimento per il satellite. Lo script calcola anche la matrice di
% rotazione Ct da ECi a LVLH.%


% RAAN Right Ascension of Ascending Node in [degrees].%
% RAAN Ascensione retta del nodo ascendente in gradi.%

RAAN=90; %[degrees]%


% inc, orbit inclination in [degrees].%
% inc, inclinazione orbitale in gradi.%

inc=101.77; %[degrees]%

% argp Argument of the Perigee in [degrees].%
% argp Argomento del perigeo in gradi.%

argp=0; %[degrees]%


% orbit frequency in [rad/s].%
% frequenza orbitale in [rad/s].%

n=9.090e-4; %[rad/s]%

% converts orbit's Right Ascension of Ascending Node from degrees to
% radians.%
% converte l'ascensione retta del nodo ascendente da gradi in radianti.%

RAANr=RAAN*pi/180; %[rad]%

% converts orbit's inclination from degrees to radians.%
% converte l'inclinazione orbitale da gradi a radianti.%

ir=inc*pi/180; %[rad]%

% generates the esplementar angle of the inclination.%
% genera l'angolo esplementare dell'inclinazine.%

esplir=-(pi-ir); %[rad]%

% converts orbit's Argument of periapsis from degrees to radians.%
% converte l'argomento del perigeo orbitale da gradi in radianti.%

argpr=argp*pi/180; %[rad]%

% generate C3(argp) elements.%
% genera gli elementi di C3(argp).%

cargp=cos(argpr);
sargp=sin(argpr);

C3argp=[cargp sargp 0; -sargp cargp 0; 0 0 1];

% generate C1(i) elements.%
% genera gli elemnti di C1(i).%

ci=cos(ir);
si=sin(ir);

C1i=[1 0 0; 0 ci si; 0 -si ci];

% generate C3(RAAN) elements.%
% genera gli elementi di C3(RAAN).%

cRAAN=cos(RAANr);
sRAAN=sin(RAANr);

C3RAAN=[cRAAN sRAAN 0; -sRAAN cRAAN 0; 0 0 1];


% generates the Rotation Matrix Ct to rotate from LVLH to ECI.%
% genera la matrice di rotazione Ct per ruotare da LVLH a ECI.%

C=C3argp*C1i*C3RAAN;

Ct=C';

% generates the "adaptation matrix" that transforms the traditional LVLH
% frame based on the Zenith to my LVLH frame based on Nadir direction.%
% genera la "matrice di adattamento" che trasforma l'LVLH tradizionale
% basato sullo Zenith nel mio sistema LVLH nasato sulla direzione del
% Nadir.%

Adapt= [0 1 0; 0 0 -1; -1 0 0];


% define the orbit radius a in [km].%
% definisce il raggio orbitale in [km].%

a=7842.6323; %[km]%


% define satellite orbit velocity module V in [km/s].%
% definisce il modulo dellavelocit tangenziale orbitale V in [km/s].%

V=n*a; %[km/s]%


% define the Earth's Gravitational constant GM=G*Mearth in [km^3sec^2].%
% definisce la costante gravitazionale della Terra GM=G*Mearth in [km^3sec^2].%

GM=398600.4418; %[km^3sec^2]%
